import classNames from 'classnames'

/**
 * The standard form radio input, shown here with a label, hint, and where applicable an error message
 *
 * **Note:** Make sure to include a label for each input used
 * */
export default {
  title: 'Components/Form/RadioInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    error: false,
  },
}

const TextTemplate = ({ disabled, error }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_text = classNames('rpf-input-radio', {
    'rpf-input-radio--error': error,
    'rpf-input-radio--disabled': disabled,
  })

  return `
    <div class="${classnames_wrapper}">
      <label for="name" class="${classnames_label}">
        Favourite coding language
        <small class="rpf-label__hint">Please select your favourite coding language</small>
      </label>
      <label class="${classnames_text}">
        <input type="radio" name="name" value="python" checked  ${ disabled ? ' disabled' : '' }/>
        Python
      </label>
      <label class="${classnames_text}">
        <input type="radio" name="name" value="ruby"  ${ disabled ? ' disabled' : '' }/>
        Ruby
      </label>
      <label class="${classnames_text}">
        <input type="radio" name="name" value="javascript"  ${ disabled ? ' disabled' : '' }/>
        JavaScript
      </label>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: Your name is required</div>'
          : ''
      }
    </div>
  `
}

export const Default = TextTemplate.bind({})
Default.args = {}

export const Error = TextTemplate.bind({})
Error.args = {
  error: true,
}

export const Disabled = TextTemplate.bind({})
Disabled.args = {
  disabled: true,
}
