import classNames from 'classnames'

/**
 * The standard form text input, shown here with a label, hint, and where applicable an error message
 *
 * **Note:** Make sure to include a label for each input used
 * */
export default {
  title: 'Components/Form/TextareaInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    readonly: false,
    error: false,
    fullWidth: false,
  },
}

const TextTemplate = ({ disabled, readonly, error, fullWidth }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_text = classNames('rpf-input rpf-input-textarea', {
    'rpf-input--error': error,
    'rpf-input--full-width': fullWidth,
  })

  return `
    <div class="${classnames_wrapper}">
      <label for="name" class="${classnames_label}">
        What is your name?
        <small class="rpf-label__hint">Please enter your first and last names</small>
      </label>
      <textarea id="name" name="name" class="${classnames_text}"${
    disabled || readonly ? ' disabled' : ''
  }>Joe Bloggs</textarea>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: Your name is required</div>'
          : ''
      }
    </div>
  `
}

export const Default = TextTemplate.bind({})
Default.args = {}

export const Error = TextTemplate.bind({})
Error.args = {
  error: true,
}

export const Readonly = TextTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Disabled = TextTemplate.bind({})
Disabled.args = {
  disabled: true,
}


export const FullWidth = TextTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}
