import '../../scss/components/layout/decorative-section.scss'

/**
 * A section component with a selection of decorations.
 *
 * Decorative sections must be followed by another `.rpf-decorative-section` with a different background as
 * the cutout is actually applied to the following `.rpf-decorative-section` for rendering reasons.
 *
 * This component does not apply any padding or margin, other than the additional padding
 * and negative margin needed for the decoration. As a result, you should **not** modify the
 * padding or margin of this component and instead wrap your content in another element.
 * */
export default {
  title: 'Components/Layout/Decorative Section',
  tags: ['autodocs'],
  argTypes: {
    decoration: {
      control: 'select',
      options: [
        'Wave (Variant 1)',
        'Wave (Variant 2)',
        'Wave (Variant 3)',
        'Slice',
      ],
      mapping: {
        'Wave (Variant 1)': 'rpf-decorative-section__wave rpf-decorative-section__wave--variant-1',
        'Wave (Variant 2)': 'rpf-decorative-section__wave rpf-decorative-section__wave--variant-2',
        'Wave (Variant 3)': 'rpf-decorative-section__wave rpf-decorative-section__wave--variant-3',
        'Slice': 'rpf-decorative-section__slice',
      }
    },
    mirrored: {
      control: 'boolean',
    },
  },
  args: {
    decoration: null,
    mirrored: false,
  },
}

const DecorativeSectionTemplate = ({ decoration, mirrored }) => {
  const className = ['rpf-decorative-section', decoration, mirrored && 'rpf-decorative-section--mirrored'].filter((n) => n).join(' ')
  return `
<section class="${className}" style="color: #fff;background-color: #CD2356;">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl. Donec euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl.
</section>
<section class="${className}" style="background-color: #FCF4F7;">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl. Donec euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl.
</section>
<section class="rpf-decorative-section" style="background-color: #FFFFFF;">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl. Donec euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl.
</section>
  `
}

export const Default = DecorativeSectionTemplate.bind({})
Default.args = {}

export const WaveVariant1 = DecorativeSectionTemplate.bind({})
WaveVariant1.args = {
  decoration: 'Wave (Variant 1)',
}

export const WaveVariant2 = DecorativeSectionTemplate.bind({})
WaveVariant2.args = {
  decoration: 'Wave (Variant 2)',
}

export const WaveVariant3 = DecorativeSectionTemplate.bind({})
WaveVariant3.args = {
  decoration: 'Wave (Variant 3)',
}

export const WaveMirrored = DecorativeSectionTemplate.bind({})
WaveMirrored.args = {
  decoration: 'Wave (Variant 1)',
  mirrored: true,
}

export const Slice = DecorativeSectionTemplate.bind({})
Slice.args = {
  decoration: 'Slice',
}

export const SliceMirrored = DecorativeSectionTemplate.bind({})
SliceMirrored.args = {
  decoration: 'Slice',
  mirrored: true,
}

const DecorationWithBackgroundsTemplate = () => {
  return `
<section class="rpf-decorative-section rpf-decorative-section__wave rpf-decorative-section__wave--variant-1" style="color: #fff;background-color: #CD2356;background-image: url(data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%2228%22%20height%3D%2249%22%20viewBox%3D%220%200%2028%2049%22%3E%3Cg%20fill-rule%3D%22evenodd%22%3E%3Cg%20id%3D%22hexagons%22%20fill%3D%22%23000%22%20fill-opacity%3D%220.2%22%20fill-rule%3D%22nonzero%22%3E%3Cpath%20d%3D%22M13.99%209.25l13%207.5v15l-13%207.5L1%2031.75v-15l12.99-7.5zM3%2017.9v12.7l10.99%206.34%2011-6.35V17.9l-11-6.34L3%2017.9zM0%2015l12.98-7.5V0h-2v6.35L0%2012.69v2.3zm0%2018.5L12.98%2041v8h-2v-6.85L0%2035.81v-2.3zM15%200v7.5L27.99%2015H28v-2.31h-.01L17%206.35V0h-2zm0%2049v-8l12.99-7.5H28v2.31h-.01L17%2042.15V49h-2z%22%2F%3E%3C%2Fg%3E%3C%2Fg%3E%3C%2Fsvg%3E);">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl. Donec euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl.
</section>
<section class="rpf-decorative-section rpf-decorative-section__wave rpf-decorative-section__wave--variant-1" style="background-color: #FCF4F7;background-image: url(data:image/svg+xml,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%22100%22%20height%3D%22100%22%20viewBox%3D%220%200%20100%20100%22%3E%3Cg%20fill-rule%3D%22evenodd%22%20fill-opacity%3D%220.1%22%3E%3Cg%20fill%3D%22%23000%22%3E%3Cpath%20opacity%3D%22.5%22%20d%3D%22M96%2095h4v1h-4v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4h-9v4h-1v-4H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15v-9H0v-1h15V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h9V0h1v15h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9h4v1h-4v9zm-1%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-9-10h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm9-10v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-9-10h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm9-10v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-9-10h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm9-10v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-10%200v-9h-9v9h9zm-9-10h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9zm10%200h9v-9h-9v9z%22%20%2F%3E%3Cpath%20d%3D%22M6%205V0H5v5H0v1h5v94h1V6h94V5H6z%22%20%2F%3E%3C%2Fg%3E%3C%2Fg%3E%3C%2Fsvg%3E%0A);">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl. Donec euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl.
</section>
<section class="rpf-decorative-section" style="background-color: #FFFFFF;background-image: url(data:image/svg+xml,%3Csvg%20width%3D%2252%22%20height%3D%2226%22%20viewBox%3D%220%200%2052%2026%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cg%20fill%3D%22none%22%20fill-rule%3D%22evenodd%22%20fill-opacity%3D%220.1%22%3E%3Cg%20fill%3D%22%23000%22%3E%3Cpath%20d%3D%22M10%2010c0-2.21-1.79-4-4-4-3.314%200-6-2.686-6-6h2c0%202.21%201.79%204%204%204%203.314%200%206%202.686%206%206%200%202.21%201.79%204%204%204%203.314%200%206%202.686%206%206%200%202.21%201.79%204%204%204v2c-3.314%200-6-2.686-6-6%200-2.21-1.79-4-4-4-3.314%200-6-2.686-6-6zm25.464-1.95l8.486%208.486-1.414%201.414-8.486-8.486%201.414-1.414z%22%20%2F%3E%3C%2Fg%3E%3C%2Fg%3E%3C%2Fsvg%3E)">
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nullam euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl. Donec euismod, nisl eget aliquam ultricies, nunc nisl aliquet nunc, quis aliquam nisl nunc eu nisl.
</section>
  `
}

export const DecorationWithBackgrounds = DecorationWithBackgroundsTemplate.bind({})

const PaddedContentExampleTemplate = () => {
  return `
<style type="text/css">
  .example-hero-container {
    padding: var(--space-4);
    margin: 0 auto;
    max-width: 1300px;
    text-align: center;
  }

  .example-hero-container h1 {
    font-size: var(--font-size-5);
    margin: 0;
  }

  .example-image-split {
    padding: var(--space-4);
    margin: 0 auto;
    max-width: 1300px;
    display: flex;
    gap: var(--space-4);
  }

  .example-image-split__img {
    flex: 2;
  }

  .example-image-split__img img {
    width: 100%;
    height: auto;
  }

  .example-image-split__content {
    flex: 3;
  }

  .example-footer-container {
    padding: var(--space-4);
    margin: 0 auto;
    max-width: 1300px;
  }

  .example-footer-container {
    display: flex;
    justify-content: stretch;
  }

  .example-footer-container ul {
    flex: 1;
    list-style-type: none;
  }

  .example-footer-container ul li a {
    color: var(--rpf-white);
  }
</style>
<section class="rpf-decorative-section rpf-decorative-section__slice rpf-decorative-section__slice--md" style="color: #fff;background-color: #CD2356;">
  <div class="example-hero-container">
    <h1>Raspberry Pi Foundation</h1>
  </div>
</section>
<section class="rpf-decorative-section rpf-decorative-section__wave rpf-decorative-section__wave--variant-2-mirrored" style="background-color: #FCF4F7;">
  <div class="example-image-split">
    <div class="example-image-split__img">
      <img alt="600x400 placeholder" src="https://placehold.co/600x400" />
    </div>
    <div class="example-image-split__content">
      <h2>Some heading</h2>
      <p>This is a pretty roughly thrown together example of some sections with the wave cutout. The styles and markup within this example do not represent best practices, nor will they necessarily have the correct font sizes and spacing. As such, it should be used for reference only.</p>
    </div>
  </div>
</section>
<section class="rpf-decorative-section" style="background-color: var(--rpf-grey-700);">
  <div class="example-footer-container">
    <ul>
      <li><a href="#">Link 1</a></li>
      <li><a href="#">Link 2</a></li>
      <li><a href="#">Link 3</a></li>
      <li><a href="#">Link 4</a></li>
      <li><a href="#">Link 5</a></li>
    </ul>
    <ul>
      <li><a href="#">Link 1</a></li>
      <li><a href="#">Link 2</a></li>
      <li><a href="#">Link 3</a></li>
      <li><a href="#">Link 4</a></li>
      <li><a href="#">Link 5</a></li>
    </ul>
  </div>
</section>
  `
}

export const PaddedContentExample = PaddedContentExampleTemplate.bind({})
